=== modified file 'src/style.cpp'
--- src/style.cpp	2011-02-21 07:59:34 +0000
+++ src/style.cpp	2011-03-04 14:51:34 +0000
@@ -336,6 +336,12 @@
     {NULL, -1}
 };
 
+static SPStyleEnum const enum_clip_rule[] = {
+    {"nonzero", SP_WIND_RULE_NONZERO},
+    {"evenodd", SP_WIND_RULE_EVENODD},
+    {NULL, -1}
+};
+
 /**
  * Release callback.
  */
@@ -768,6 +774,9 @@
     SPS_READ_PENUM_IF_UNSET(&style->enable_background, repr,
                             "enable-background", enum_enable_background, true);
 
+    /* clip-rule */
+    SPS_READ_PENUM_IF_UNSET(&style->clip_rule, repr, "clip-rule", enum_clip_rule, true);
+
     /* 3. Merge from parent */
     if (object) {
         if (object->parent) {
@@ -1021,7 +1030,9 @@
             style->object->getRepr()->setAttribute("clip-path", val);
             break;
         case SP_PROP_CLIP_RULE:
-            g_warning("Unimplemented style property SP_PROP_CLIP_RULE: value: %s", val);
+            if (!style->clip_rule.set) {
+                sp_style_read_ienum(&style->clip_rule, val, enum_clip_rule, true);
+            }
             break;
         case SP_PROP_MASK:
             /** \todo
@@ -1646,6 +1657,11 @@
     if(style->enable_background.inherit) {
         style->enable_background.value = parent->enable_background.value;
     }
+
+    /* Clipping */
+    if (!style->clip_rule.set || style->clip_rule.inherit) {
+        style->clip_rule.computed = parent->clip_rule.computed;
+    }
 }
 
 template <typename T>
@@ -1907,7 +1923,7 @@
     /* Enum values that don't have any relative settings (other than `inherit'). */
     {
         SPIEnum SPStyle::*const fields[] = {
-            //nyi: SPStyle::clip_rule,
+            &SPStyle::clip_rule,
             //nyi: SPStyle::color_interpolation,
             //nyi: SPStyle::color_interpolation_filters,
             //nyi: SPStyle::color_rendering,
@@ -2447,6 +2463,9 @@
 
     p += sp_style_write_ienum(p, c + BMAX - p, "enable-background", enum_enable_background, &style->enable_background, NULL, flags);
 
+    /* clipping */
+    p += sp_style_write_ienum(p, c + BMAX - p, "clip-rule", enum_clip_rule, &style->clip_rule, NULL, flags);
+
     /* fixme: */
     p += sp_text_style_write(p, c + BMAX - p, style->text, flags);
 
@@ -2593,6 +2612,8 @@
 
     p += sp_text_style_write(p, c + BMAX - p, from->text, SP_STYLE_FLAG_IFDIFF);
 
+    p += sp_style_write_ienum(p, c + BMAX - p, "clip-rule", enum_clip_rule, &from->clip_rule, &to->clip_rule, SP_STYLE_FLAG_IFDIFF);
+
     /** \todo
      * The reason we use IFSET rather than IFDIFF is the belief that the IFDIFF
      * flag is mainly only for attributes that don't handle explicit unset well.
@@ -2784,6 +2805,8 @@
     style->enable_background.value = SP_CSS_BACKGROUND_ACCUMULATE;
     style->enable_background.set = false;
     style->enable_background.inherit = false;
+
+    style->clip_rule.value = style->clip_rule.computed = SP_WIND_RULE_NONZERO;
 }
 
 
@@ -4179,6 +4202,9 @@
     if (style->enable_background.set) {
         repr->setAttribute("enable-background", NULL);
     }
+    if (style->clip_rule.set) {
+        repr->setAttribute("clip-rule", NULL);
+    }
 }
 
 /**

=== modified file 'src/style.h'
--- src/style.h	2011-02-27 20:48:16 +0000
+++ src/style.h	2011-03-04 14:43:12 +0000
@@ -327,9 +327,11 @@
     unsigned cursor_set : 1;
     unsigned overflow_set : 1;
     unsigned clip_path_set : 1;
-    unsigned clip_rule_set : 1;
     unsigned mask_set : 1;
 
+    /** clip-rule: 0 nonzero, 1 evenodd */
+    SPIEnum clip_rule;
+
     /** display */
     SPIEnum display;
 

